# coding: utf-8

"""
    ORY Keto

    A cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.1
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import ory_keto_client
from ory_keto_client.api.engines_api import EnginesApi  # noqa: E501
from ory_keto_client.rest import ApiException


class TestEnginesApi(unittest.TestCase):
    """EnginesApi unit test stubs"""

    def setUp(self):
        self.api = ory_keto_client.api.engines_api.EnginesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_ory_access_control_policy_role_members(self):
        """Test case for add_ory_access_control_policy_role_members

        Add a member to an ORY Access Control Policy Role  # noqa: E501
        """
        pass

    def test_delete_ory_access_control_policy(self):
        """Test case for delete_ory_access_control_policy

        """
        pass

    def test_delete_ory_access_control_policy_role(self):
        """Test case for delete_ory_access_control_policy_role

        Delete an ORY Access Control Policy Role  # noqa: E501
        """
        pass

    def test_do_ory_access_control_policies_allow(self):
        """Test case for do_ory_access_control_policies_allow

        Check if a request is allowed  # noqa: E501
        """
        pass

    def test_get_ory_access_control_policy(self):
        """Test case for get_ory_access_control_policy

        """
        pass

    def test_get_ory_access_control_policy_role(self):
        """Test case for get_ory_access_control_policy_role

        Get an ORY Access Control Policy Role  # noqa: E501
        """
        pass

    def test_list_ory_access_control_policies(self):
        """Test case for list_ory_access_control_policies

        """
        pass

    def test_list_ory_access_control_policy_roles(self):
        """Test case for list_ory_access_control_policy_roles

        List ORY Access Control Policy Roles  # noqa: E501
        """
        pass

    def test_remove_ory_access_control_policy_role_members(self):
        """Test case for remove_ory_access_control_policy_role_members

        Remove a member from an ORY Access Control Policy Role  # noqa: E501
        """
        pass

    def test_upsert_ory_access_control_policy(self):
        """Test case for upsert_ory_access_control_policy

        """
        pass

    def test_upsert_ory_access_control_policy_role(self):
        """Test case for upsert_ory_access_control_policy_role

        Upsert an ORY Access Control Policy Role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ORY Keto

    A cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.37
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ory_keto_client.configuration import Configuration


class AddOryAccessControlPolicyRoleMembers(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'body': 'AddOryAccessControlPolicyRoleMembersBody',
        'flavor': 'str',
        'id': 'str'
    }

    attribute_map = {
        'body': 'Body',
        'flavor': 'flavor',
        'id': 'id'
    }

    def __init__(self, body=None, flavor=None, id=None, local_vars_configuration=None):  # noqa: E501
        """AddOryAccessControlPolicyRoleMembers - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._body = None
        self._flavor = None
        self._id = None
        self.discriminator = None

        if body is not None:
            self.body = body
        self.flavor = flavor
        self.id = id

    @property
    def body(self):
        """Gets the body of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501


        :return: The body of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501
        :rtype: AddOryAccessControlPolicyRoleMembersBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this AddOryAccessControlPolicyRoleMembers.


        :param body: The body of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501
        :type: AddOryAccessControlPolicyRoleMembersBody
        """

        self._body = body

    @property
    def flavor(self):
        """Gets the flavor of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501

        The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\".  in: path  # noqa: E501

        :return: The flavor of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501
        :rtype: str
        """
        return self._flavor

    @flavor.setter
    def flavor(self, flavor):
        """Sets the flavor of this AddOryAccessControlPolicyRoleMembers.

        The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\".  in: path  # noqa: E501

        :param flavor: The flavor of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and flavor is None:  # noqa: E501
            raise ValueError("Invalid value for `flavor`, must not be `None`")  # noqa: E501

        self._flavor = flavor

    @property
    def id(self):
        """Gets the id of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501

        The ID of the ORY Access Control Policy Role.  in: path  # noqa: E501

        :return: The id of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddOryAccessControlPolicyRoleMembers.

        The ID of the ORY Access Control Policy Role.  in: path  # noqa: E501

        :param id: The id of this AddOryAccessControlPolicyRoleMembers.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddOryAccessControlPolicyRoleMembers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddOryAccessControlPolicyRoleMembers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ORY Keto

    Ory Keto is a cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.46
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "ory-keto-client"
VERSION = "v0.0.0-alpha.46"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="ORY Keto",
    author="ORY",
    author_email="hi@ory.sh",
    url="https://github.com/ory/sdk",
    keywords=["OpenAPI", "OpenAPI-Generator", "ORY Keto"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache 2.0",
    long_description="""\
    Ory Keto is a cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501
    """
)



# coding: utf-8

# flake8: noqa

"""
    ORY Keto

    Ory Keto is a cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.46
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "v0.0.0-alpha.46"

# import apis into sdk package
from ory_keto_client.api.engines_api import EnginesApi
from ory_keto_client.api.health_api import HealthApi
from ory_keto_client.api.version_api import VersionApi

# import ApiClient
from ory_keto_client.api_client import ApiClient
from ory_keto_client.configuration import Configuration
from ory_keto_client.exceptions import OpenApiException
from ory_keto_client.exceptions import ApiTypeError
from ory_keto_client.exceptions import ApiValueError
from ory_keto_client.exceptions import ApiKeyError
from ory_keto_client.exceptions import ApiException
# import models into sdk package
from ory_keto_client.models.add_ory_access_control_policy_role_members_body import AddOryAccessControlPolicyRoleMembersBody
from ory_keto_client.models.authorization_result import AuthorizationResult
from ory_keto_client.models.health_not_ready_status import HealthNotReadyStatus
from ory_keto_client.models.health_status import HealthStatus
from ory_keto_client.models.inline_response500 import InlineResponse500
from ory_keto_client.models.ory_access_control_policy import OryAccessControlPolicy
from ory_keto_client.models.ory_access_control_policy_allowed_input import OryAccessControlPolicyAllowedInput
from ory_keto_client.models.ory_access_control_policy_role import OryAccessControlPolicyRole
from ory_keto_client.models.version import Version

